#
# spec file for package fonttosfnt
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fonttosfnt
Version:        1.1.0
Release:        3.3.1
Summary:        Utility to wrap a bitmap font in a sfnt (TrueType) wrapper
License:        MIT
Group:          System/X11/Utilities
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.bz2
Patch0:         0001-don-t-add-arbitrary-number-to-the-glypth-metrics.patch
Patch1:         0002-use-zero-lineGap-sTypoDescender-should-be-negative.patch
Patch2:         0003-truncate-foundry-if-there-is-no-known-abbreviation.patch
Patch3:         0004-remove-now-obsolete-comment-too.patch
Patch4:         0005-correctly-set-OS2-fsSelection-for-italic-and-bold-fo.patch
Patch5:         0006-use-standard-C-rounding-functions.patch
Patch6:         0007-use-more-properties-according-to-XLFD.patch
Patch7:         0008-use-design-metrics-in-eblc-instead-of-calculated-met.patch
Patch8:         0009-provide-version-5-OS-2-table.patch
Patch9:         0010-Add-warnings-when-wrapping-multiple-fonts-and-on-PCF.patch
Patch10:        0011-move-metrics-calculation-to-write.c.patch
Patch11:        0012-calculate-capHeight-and-xHeight-as-recommended.patch
Patch12:        0013-fix-sign-of-sTypoDescender.patch
Patch13:        0014-use-PIXEL_SIZE-to-calculate-lineGap.patch
Patch14:        0015-Fix-incorrect-error-handling-in-macTime.patch
Patch15:        0016-Fix-uninitialised-memory-write.patch
Patch16:        0017-Guess-Regular-style-for-Medium-Weight.patch
Patch17:        0018-remove-leftover-debug-printf.patch
Patch18:        0019-handle-empty-foundry-encoded-as-NULL.patch
Patch19:        0020-fix-sign-of-calculated-descent.patch
Patch20:        0021-Fall-back-to-using-FONT-property-as-family-name.patch
Patch21:        0022-writeFile-avoid-file-leak-on-errors.patch
Patch22:        0001-1em-is-font-size-not-heigh.patch
Patch23:        0023-Fail-if-ftell-fails.patch
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fontenc)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto)
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Wrap a bitmap font or a set of bitmap fonts in a sfnt (TrueType or
OpenType) wrapper.

%prep
%setup -q
%autopatch -p1

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc README.md
%license COPYING
%{_bindir}/fonttosfnt
%{_mandir}/man1/fonttosfnt.1%{?ext_man}

%changelog
* Thu Aug  5 2021 alarrosa@suse.com
- Add patch making this effectively the same as fonttosfnt 1.2.2:
  * 0023-Fail-if-ftell-fails.patch
* Mon Dec 21 2020 alarrosa@suse.com
- Add changes to make this effectively the same as fonttosfnt 1.2.1:
  * 0022-writeFile-avoid-file-leak-on-errors.patch
- At some point in the past, the following patches from 1.2.0 were also added:
  * 0018-remove-leftover-debug-printf.patch
  * 0019-handle-empty-foundry-encoded-as-NULL.patch
  * 0020-fix-sign-of-calculated-descent.patch
  * 0021-Fall-back-to-using-FONT-property-as-family-name.patch
* Fri Nov  6 2020 alarrosa@suse.com
- Add patch from https://gitlab.freedesktop.org/xorg/app/fonttosfnt/-/merge_requests/11
  to fix more metric calculations (boo#1174895):
  * 0001-1em-is-font-size-not-heigh.patch
* Tue Sep 22 2020 alarrosa@suse.com
- Add more patches from upstream's master branch:
  * 0015-Fix-incorrect-error-handling-in-macTime.patch
  * 0016-Fix-uninitialised-memory-write.patch
  * 0017-Guess-Regular-style-for-Medium-Weight.patch
* Tue Aug 25 2020 alarrosa@suse.com
- Add patches from https://gitlab.freedesktop.org/xorg/app/fonttosfnt/-/merge_requests/7
  to fix metrics (boo#1174895):
  * 0001-don-t-add-arbitrary-number-to-the-glypth-metrics.patch
  * 0002-use-zero-lineGap-sTypoDescender-should-be-negative.patch
  * 0003-truncate-foundry-if-there-is-no-known-abbreviation.patch
  * 0004-remove-now-obsolete-comment-too.patch
  * 0005-correctly-set-OS2-fsSelection-for-italic-and-bold-fo.patch
  * 0006-use-standard-C-rounding-functions.patch
  * 0007-use-more-properties-according-to-XLFD.patch
  * 0008-use-design-metrics-in-eblc-instead-of-calculated-met.patch
  * 0009-provide-version-5-OS-2-table.patch
  * 0010-Add-warnings-when-wrapping-multiple-fonts-and-on-PCF.patch
  * 0011-move-metrics-calculation-to-write.c.patch
  * 0012-calculate-capHeight-and-xHeight-as-recommended.patch
  * 0013-fix-sign-of-sTypoDescender.patch
  * 0014-use-PIXEL_SIZE-to-calculate-lineGap.patch
- Use %%license
* Tue Jan  7 2020 sndirsch@suse.com
- Update to version 1.1.0
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Correct a string literal
  * Mention .otb as an extension
  * Accept a BDF font on stdin
  * Avoid undefined behaviour
  * Round font size to integer value when reading bitmap font
  * Mark vsprintf_alloc as printf-like function
  * check for freetype NULL atoms
  * let freetype handle ISO-8859-1 mapping
  * allow ISO-646.1991-IRV as well, adobe standard for bdf
* Fri Aug 17 2018 sndirsch@suse.com
- Update to version 1.0.5
  * Is it a bird? is it a plane? No it's a fonttofs.. fontstof..
    fonttofn... it's a release of the tool that wraps a bitmap
    font into a truetype wrapper! Bringing you the last 9 years
    of exciting changes including ansification and lots of
    autotools cleanup changes, because that is how we rolled 7
    years ago. (Almost) no source files were harmed in the
    making of this release.
- get rid of _service/_servicedata files
* Wed May 31 2017 zaitor@opensuse.org
- Update to version 1.0.5+20170126.aead36f:
  * config:
  - Replace deprecated AM_CONFIG_HEADER with AC_CONFIG_HEADERS.
  - Move man pages into their own directory.
  - Add missing AC_CONFIG_SRCDIR.
  * man:
  - Remove trailing spaces and tabs.
  - Replace hard coded man page section with substitution
    strings.
  * configure: Drop AM_MAINTAINER_MODE.
  * autogen.sh:
  - Honor NOCONFIGURE=1.
  - Use exec instead of waiting for configure to finish.
  - Use quoted string variables.
  - Add default patch prefix.
- Switch to source service git checkout.
- Following the above, add libtool BuildRequires, and pass
  NOCONFIGURE=1 ./autogen.sh: Needed now that we build from a git
  checkout.
- Add pkgconfig(xorg-macros) BuildRequires: New dependency.
- Stop packaging ChangeLog and NEWS, dropped upstream.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split fonttosfnt from xorg-x11. Initial version: 1.0.4.
